@@ -749,7 +749,7 @@ cpl_error_code qmost_extract_qc (
                                              itrace+1);
             }
         }
-        else {
+        else if(isfinite(medflux)) {
             if(trace_medflux_minspc < 0 ||
                medflux < trace_medflux_min) {
                 trace_medflux_min = medflux;
@@ -794,7 +794,7 @@ cpl_error_code qmost_extract_qc (
                                              itrace+1);
             }
         }
-        else {
+        else if(isfinite(medsnr)) {
             if(trace_medsnr_minspc < 0 ||
                medsnr < trace_medsnr_min) {
                 trace_medsnr_min = medsnr;
@@ -841,7 +841,7 @@ cpl_error_code qmost_extract_qc (
                                                  itrace+1);
                 }
             }
-            else {
+            else if(isfinite(meanflux)) {
                 if(cpl_table_set(fibinfo_tbl,
                                  colname_meanflux,
                                  itrace,
