@@ -601,6 +601,20 @@ cpl_error_code qmost_fibtabload (
             }
 
             nsimucal++;
+
+            /* Sort by slit position */
+            reflist = cpl_propertylist_new();
+            cpl_propertylist_append_bool(reflist, "SLIT_POS", 0);
+
+            if(cpl_table_sort(shuftab, reflist) != CPL_ERROR_NONE) {
+                TIDY;
+                return cpl_error_set_message(cpl_func, cpl_error_get_code(),
+                                             "failed to sort by SLIT_POS in "
+                                             "output FIBINFO table");
+            }
+
+            cpl_propertylist_delete(reflist);
+            reflist = NULL;
         }
 
         if(nsimucal > 0) {
